==> gnome-builder-3.16.3.tar.xz: gnome-builder-3.16.3/libide/ide-enums.h <==

/* Generated data (by glib-mkenums) */

#ifndef __IDE_ENUMS_H__
#define __IDE_ENUMS_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "./doap/ide-doap.h" */
GType ide_doap_error_get_type (void);
#define IDE_TYPE_DOAP_ERROR (ide_doap_error_get_type ())

/* enumerations from "./ide-buffer.h" */
GType ide_buffer_line_flags_get_type (void);
#define IDE_TYPE_BUFFER_LINE_FLAGS (ide_buffer_line_flags_get_type ())

/* enumerations from "./ide-diagnostic.h" */
GType ide_diagnostic_severity_get_type (void);
#define IDE_TYPE_DIAGNOSTIC_SEVERITY (ide_diagnostic_severity_get_type ())

/* enumerations from "./ide-highlighter.h" */
GType ide_highlight_result_get_type (void);
#define IDE_TYPE_HIGHLIGHT_RESULT (ide_highlight_result_get_type ())

/* enumerations from "./ide-indent-style.h" */
GType ide_indent_style_get_type (void);
#define IDE_TYPE_INDENT_STYLE (ide_indent_style_get_type ())

/* enumerations from "./ide-source-view.h" */
GType ide_source_view_mode_type_get_type (void);
#define IDE_TYPE_SOURCE_VIEW_MODE_TYPE (ide_source_view_mode_type_get_type ())
GType ide_source_view_theatric_get_type (void);
#define IDE_TYPE_SOURCE_VIEW_THEATRIC (ide_source_view_theatric_get_type ())
GType ide_source_view_movement_get_type (void);
#define IDE_TYPE_SOURCE_VIEW_MOVEMENT (ide_source_view_movement_get_type ())

/* enumerations from "./ide-thread-pool.h" */
GType ide_thread_pool_kind_get_type (void);
#define IDE_TYPE_THREAD_POOL_KIND (ide_thread_pool_kind_get_type ())
G_END_DECLS

#endif /* __IDE_ENUMS_H__ */

/* Generated data ends here */

==> gnome-builder_3.18.1.orig.tar.xz: gnome-builder-3.18.1/libide/ide-enums.h <==

/* Generated data (by glib-mkenums) */

#ifndef __IDE_ENUMS_H__
#define __IDE_ENUMS_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "./doap/ide-doap.h" */
GType ide_doap_error_get_type (void);
#define IDE_TYPE_DOAP_ERROR (ide_doap_error_get_type ())

/* enumerations from "./ide-buffer.h" */
GType ide_buffer_line_flags_get_type (void);
#define IDE_TYPE_BUFFER_LINE_FLAGS (ide_buffer_line_flags_get_type ())

/* enumerations from "./ide-diagnostic.h" */
GType ide_diagnostic_severity_get_type (void);
#define IDE_TYPE_DIAGNOSTIC_SEVERITY (ide_diagnostic_severity_get_type ())

/* enumerations from "./ide-highlighter.h" */
GType ide_highlight_result_get_type (void);
#define IDE_TYPE_HIGHLIGHT_RESULT (ide_highlight_result_get_type ())

/* enumerations from "./ide-indent-style.h" */
GType ide_indent_style_get_type (void);
#define IDE_TYPE_INDENT_STYLE (ide_indent_style_get_type ())

/* enumerations from "./ide-source-view.h" */
GType ide_source_view_mode_type_get_type (void);
#define IDE_TYPE_SOURCE_VIEW_MODE_TYPE (ide_source_view_mode_type_get_type ())
GType ide_source_view_theatric_get_type (void);
#define IDE_TYPE_SOURCE_VIEW_THEATRIC (ide_source_view_theatric_get_type ())
GType ide_source_view_movement_get_type (void);
#define IDE_TYPE_SOURCE_VIEW_MOVEMENT (ide_source_view_movement_get_type ())

/* enumerations from "./ide-symbol.h" */
GType ide_symbol_kind_get_type (void);
#define IDE_TYPE_SYMBOL_KIND (ide_symbol_kind_get_type ())
GType ide_symbol_flags_get_type (void);
#define IDE_TYPE_SYMBOL_FLAGS (ide_symbol_flags_get_type ())

/* enumerations from "./ide-thread-pool.h" */
GType ide_thread_pool_kind_get_type (void);
#define IDE_TYPE_THREAD_POOL_KIND (ide_thread_pool_kind_get_type ())
G_END_DECLS

#endif /* __IDE_ENUMS_H__ */

/* Generated data ends here */
